@@ -14,14 +14,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
 import time
 
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_serialization import jsonutils
 
-from monasca_common.kafka import consumer
-from monasca_common.kafka import producer
+from monasca_common.kafka import client_factory
 from monasca_notification.common.repositories import exceptions
 from monasca_notification.common.utils import construct_notification_object
 from monasca_notification.common.utils import get_db_repo
@@ -34,24 +33,26 @@ CONF = cfg.CONF
 
 class PeriodicEngine(object):
     def __init__(self, period):
-        self._topic_name = CONF.kafka.periodic[period]
+        self._topic_name = CONF.kafka.periodic[str(period)]
 
         self._statsd = get_statsd_client()
 
-        zookeeper_path = CONF.zookeeper.periodic_path[period]
-        self._consumer = consumer.KafkaConsumer(CONF.kafka.url,
-                                                ','.join(CONF.zookeeper.url),
-                                                zookeeper_path,
-                                                CONF.kafka.group,
-                                                self._topic_name)
-
-        self._producer = producer.KafkaProducer(CONF.kafka.url)
+        self._consumer = client_factory.get_kafka_consumer(
+            CONF.kafka.url,
+            CONF.kafka.group,
+            self._topic_name,
+            CONF.zookeeper.url,
+            CONF.zookeeper.periodic_path[str(period)],
+            CONF.kafka.legacy_kafka_client_enabled)
+        self._producer = client_factory.get_kafka_producer(
+            CONF.kafka.url,
+            CONF.kafka.legacy_kafka_client_enabled)
 
         self._notifier = notification_processor.NotificationProcessor()
         self._db_repo = get_db_repo()
         self._period = period
 
-    def _keep_sending(self, alarm_id, original_state, type, period):
+    def _keep_sending(self, alarm_id, original_state, period):
         try:
             current_state = self._db_repo.get_alarm_current_state(alarm_id)
         except exceptions.DatabaseException:
@@ -67,15 +68,13 @@ class PeriodicEngine(object):
         # Period changed
         if period != self._period:
             return False
-        if type != "webhook":
-            return False
 
         return True
 
     def run(self):
         for raw_notification in self._consumer:
-            message = raw_notification[1].message.value
-            notification_data = json.loads(message)
+            message = raw_notification.value()
+            notification_data = jsonutils.loads(message)
 
             notification = construct_notification_object(self._db_repo, notification_data)
 
@@ -85,7 +84,6 @@ class PeriodicEngine(object):
 
             if self._keep_sending(notification.alarm_id,
                                   notification.state,
-                                  notification.type,
                                   notification.period):
 
                 wait_duration = notification.period - (
